#ifndef CELP_FILTERS_H

typedef struct {
    int32_t k;			//  12-bit fractional subfield
    int32_t alpha;		//  12-bit fractional subfield
    int32_t prev_in;
    int32_t prev_out;
} filter_state;


int32_t order_1_high_filter(filter_state *state,
                            int32_t in);


/*
 * When discretizing first-order filters, the constant k
 * can be found simply, at corner frequencies far lower than the
 * Nyquis Frequency, like so:
 *
 * omega = 2 * Pi * F
 * k = h / (h + omega)
 *
 * Where,
 *
 * F: Corner Frequency
 * h: Sample Rate
 *
 * A more accurate computation for k could be:
 *
 * omega_prime = 2 * sin( Pi * F / h )
 * k = 1 / (1 + omega_prime)
 *
 * In spite of very accurate methods, the correct values for k
 * can be approximated in many signal-processing applications...
 *
 */


//  First order, high-pass filter, 50Hz
extern filter_state mike_in;

//  Second order, high-pass filter, 200Hz, State 1
extern filter_state out_hp1;

//  Second order, high-pass filter, 200Hz, State 2
extern filter_state out_hp2;

//  First LP Corner, Frequency Estimator, 200Hz
extern filter_state in_fe1;

//  Second LP Corner, Frequency Estimator, 50Hz
extern filter_state in_fe2;

//  First LP Corner, Ouput Integrator, 200Hz, DC Gain = 4
extern filter_state out_lp1;

// Second LP Corner, Output Integrator, 1.33kHz, DC Gain = 4
extern filter_state out_lp2;


#define CELP_FILTERS_H
#endif
